@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 import pandas
 
 from hts import HTSRegressor
@@ -74,3 +76,30 @@ def test_predict_regressor_visnights(load_df_and_hier_visnights):
         assert "NSW" in ht.hts_result.errors
         assert "NSW" in ht.hts_result.forecasts
         assert "NSW" in ht.hts_result.residuals
+
+
+def test_exog_fit_predict_fb_model(hierarchical_mv_data, mv_tree_empty):
+    exogenous = {
+        k: ["precipitation", "temp"]
+        for k in hierarchical_mv_data.columns
+        if k not in ["precipitation", "temp"]
+    }
+    horizon = 7
+    train = hierarchical_mv_data[:500]
+    test = hierarchical_mv_data[500 : 500 + horizon]
+    clf = HTSRegressor(model="prophet", revision_method="OLS", n_jobs=0)
+    model = clf.fit(train, mv_tree_empty, exogenous=exogenous)
+    preds = model.predict(exogenous_df=test)
+    assert isinstance(preds, pandas.DataFrame)
+
+    # base + steps ahead
+    assert len(preds) == len(train) + horizon
+    assert len(model.hts_result.forecasts["total"]) == len(train) + horizon
+
+    assert len(model.hts_result.errors) == len(train.columns) - 2
+
+    for column in train.columns:
+        if column not in ("precipitation", "temp"):
+            assert column in model.hts_result.errors
+            assert column in model.hts_result.forecasts
+            assert column in model.hts_result.residuals
